import { Module } from '@nestjs/common';
import { AppController } from './app.controller';
import { AppService } from './app.service';
import { config } from 'dotenv';
import { TypeOrmModule } from '@nestjs/typeorm';
import { NewsletterModule } from './core/newsletter/newsletter.module';
import { UsersModule } from './core/users/users.module';
import { MailerModule } from './core/mailer/mailer.module';
import { AuthModule } from './core/auth/auth.module';
import { CartModule } from './core/cart/cart.module';
import { StripeModule } from './core/stripe/stripe.module';
import { BooksModule } from './feature/books/books.module';
import { FeaturedBookModule } from './feature/featured-book/featured-book.module';
import { MyBooksModule } from './feature/my-books/books.module';

config();

@Module({
  imports: [
    TypeOrmModule.forRoot({
      type: 'postgres',
      host: `${process.env.POSTGRES_HOST}`,
      port: +`${process.env.POSTGRES_PORT}`,
      username: `${process.env.POSTGRES_USER}`,
      password: `${process.env.POSTGRES_PASSWORD}`,
      database: `${process.env.POSTGRES_DATABASE}`,
      entities: ['dist/**/*.entity.{ts,js}'],
      // entities: [__dirname + '/**/*.entity.{ts,js}'],
      ssl: `${process.env.POSTGRES_SSL}`.toLowerCase() == 'true',
      synchronize: false,
    }),
    NewsletterModule,
    UsersModule,
    MailerModule,
    AuthModule,
    CartModule,
    StripeModule,
    BooksModule,
    FeaturedBookModule,
    MyBooksModule,
  ],
  controllers: [AppController],
  providers: [AppService],
})
export class AppModule {}
