import {
  Controller,
  Headers,
  InternalServerErrorException,
  Post,
  RawBodyRequest,
  Req,
} from '@nestjs/common';
import { StripeService } from './stripe.service';
import { PaymentIntentsService } from 'src/core/stripe/payment-intents.service';
import { CartService } from '../cart/cart.service';
import { MyBooksService } from 'src/feature/my-books/books.service';
import { config } from 'dotenv';
config();

const stripe = require('stripe')(`${process.env.STRIPE_SECRET_KEY}`);

// const endpointSecret =
//   'whsec_27acada239caa3bb50e540477a9c7c5096490da790e58572f37561df4d3c04e4';
const endpointSecret = `${process.env.STRIPE_WEBHOOK_SECRET_KEY}`;

@Controller('stripe')
export class StripeController {
  constructor(
    private booksMyBooksService: MyBooksService,
    private paymentIntentsService: PaymentIntentsService,
    private stripeService: StripeService,
    private cartService: CartService,
  ) {}

  @Post('webhook')
  async webhook(@Req() req: RawBodyRequest<Request>, @Headers() headers) {
    const sig = headers['stripe-signature'];
    let result: any = true;
    let event;

    try {
      event = stripe.webhooks.constructEvent(req.rawBody, sig, endpointSecret);
      console.log('hook: ', event);
    } catch (err) {
      return `Webhook Error: ${err.message}`;
    }

    switch (event.type) {
      case 'checkout.session.completed':
        result = await this.paymentIntentsService.createPaymentIntent(
          event.data.object.metadata.userId,
          event.data.object.metadata.itemsIds,
          event.data.object.payment_intent,
        );
        console.log(
          'CHECKOUT SESSION COMPLETE',
          new Date(),
          event.data.object.payment_intent,
          event.data.object.metadata,
        );
        break;
      case 'payment_intent.succeeded':
        try {
          setTimeout(async () => {
            const paymentIntentSucceeded = event.data.object;
            const paymentIntentObj = await this.paymentIntentsService.findOne(
              paymentIntentSucceeded.id,
            );
            console.log('FOUND PAYMENT_INTENT', new Date(), paymentIntentObj);
            if (paymentIntentObj) {
              const idsAr = this.stripeService.getIdsAsArray(
                paymentIntentObj.itemsIds,
              );
              result = await this.booksMyBooksService.addBooksToUser(
                paymentIntentObj.userId,
                idsAr,
              );

              this.paymentIntentsService.delete(
                paymentIntentObj.paymentIntentId,
              );

              await this.paymentIntentsService.delete(
                paymentIntentObj.paymentIntentId,
              );
              await this.cartService.delete(paymentIntentObj.userId);
            } else {
              throw new InternalServerErrorException(
                'Payment intent not found!',
              );
            }
          }, 2000);
        } catch (e) {
          console.log('ERROR PAYMENT SUCCESS: ', e);
        }
        break;
      default:
        console.log(`Unhandled event type ${event.type}`);
    }
    return result;
  }
}
