import {
  Body,
  Controller,
  Get,
  Delete,
  Param,
  NotFoundException,
  UseGuards,
  Put,
} from '@nestjs/common';
import { UsersService } from './users.service';
import { CurrentUser } from './decorators/current-user.decorator';
import { User } from './user.entity';
import { JwtGuard } from '../auth/guards/jwt-auth.guard';
@Controller('users')
export class UsersController {
  constructor(private usersService: UsersService) {}

  @Get('profile')
  @UseGuards(JwtGuard)
  getProfile(@CurrentUser() user: User) {
    return this.usersService.getProfile(user);
  }

  @Put('profile')
  @UseGuards(JwtGuard)
  updateUser(
    @CurrentUser() user: User,
    @Body()
    body: {
      firstname?: string;
      lastname?: string;
    },
  ) {
    console.log(' PUT USER: ', body);
    return this.usersService.updateProfile(
      user.id,
      body.firstname,
      body.lastname,
    );
  }

  @Get(':id')
  async findUser(@Param('id') id: string) {
    const user = await this.usersService.findOne(parseInt(id));
    if (!user) {
      throw new NotFoundException('User not found');
    }
    return user;
  }

  @Delete(':id')
  removeUser(@Param('id') id: string) {
    return this.usersService.remove(parseInt(id));
  }
}
