import {
  Controller,
  Get,
  Param,
  Put,
  UnauthorizedException,
  UseGuards,
} from '@nestjs/common';
import { User } from 'src/core/users/user.entity';
import { FeaturedBookService } from './featured-book.service';
import { JwtGuard } from 'src/core/auth/guards/jwt-auth.guard';
import { config } from 'dotenv';
import { CurrentUser } from 'src/core/users/decorators/current-user.decorator';

config();

@Controller('featured-book')
export class FeaturedBookController {
  adminEmail = `${process.env.ADMIN_EMAIL}`;
  constructor(private booksService: FeaturedBookService) {}

  @Put(':id')
  @UseGuards(JwtGuard)
  setFeatureBook(@CurrentUser() user: User, @Param('id') id: number) {
    if (user && user.email === this.adminEmail)
      return this.booksService.setFeaturedBook(id);
    throw new UnauthorizedException(
      'You are not authorized to feature the book',
    );
  }

  @Get()
  getFeatureBook() {
    return this.booksService.getFeatureBook();
  }
}
