import { Injectable, InternalServerErrorException } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Repository } from 'typeorm';
import { MyBook } from './my-book.entity';
import { BooksService } from '../books/books.service';

@Injectable()
export class MyBooksService {
  constructor(
    @InjectRepository(MyBook) private repo: Repository<MyBook>,
    private booksService: BooksService,
  ) {}

  async addBooksToUser(userId: number, idsAr: number[]) {
    try {
      idsAr.forEach(async (bookId) => {
        const obj = this.repo.create();
        obj.userId = userId;
        obj.bookId = bookId;
        await this.repo.save(obj);
      });
    } catch (e) {
      throw new InternalServerErrorException('Error adding books to user! ', e);
    }
  }

  async getMyBooks(userId: number, take: number, skip: number) {
    let books = [];
    const results = await this.repo.find({
      where: {
        userId,
      },
    });
    if (results && results.length > 0) {
      const ids = results.map((t) => t.bookId);
      return this.booksService.getAllForIds(ids, take, skip);
    }

    return books;
  }

  async isOneOfMyBooks(userId: number, bookId: number) {
    const exists = await this.repo.exists({
      where: {
        userId,
        bookId,
      },
    });
    return exists;
  }
}
