import { Routes } from '@angular/router';
import { HomeComponent } from './pages/home/home.component';
import { SigninComponent } from './pages/signin/signin.component';
import { SignupComponent } from './pages/signup/signup.component';
import { AboutComponent } from './pages/about/about.component';
import { AddBookComponent } from './pages/add-book/add-book.component';
import { ForgetPasswordComponent } from './pages/forget-password/forget-password.component';
import { authGuard } from './guards/auth.guard';
import { NotFoundComponent } from './pages/not-found/not-found.component';
import { RefundPolicyComponent } from './policies/refund-policy/refund-policy.component';
import { PrivacyPolicyComponent } from './policies/privacy-policy/privacy-policy.component';
import { TermsAndConditionsComponent } from './policies/terms-and-conditions/terms-and-conditions.component';
import { CookiesPolicyComponent } from './policies/cookies-policy/cookies-policy.component';
import { DmcaPolicyComponent } from './policies/dmca-policy/dmca-policy.component';
import { CopyrightNoticeComponent } from './policies/copyright-notice/copyright-notice.component';
import { TermsOfSaleComponent } from './policies/terms-of-sale/terms-of-sale.component';
import { ContactComponent } from './pages/contact/contact.component';
import { BookDetailsComponent } from './pages/book-details/book-details.component';
import { ProfileComponent } from './pages/profile/profile.component';
import { ResetPasswordComponent } from './pages/reset-password/reset-password.component';
import { adminGuard } from './guards/admin.guard';
import { ManageBooksComponent } from './pages/manage-books/manage-books.component';
import { MyBooksComponent } from './pages/my-books/my-books.component';
import { SearchComponent } from './pages/search/search.component';
import { CartComponent } from './pages/cart/cart.component';

export const routes: Routes = [
  { path: '', redirectTo: 'home', pathMatch: 'full' },
  { path: 'home', component: HomeComponent },
  { path: 'about', component: AboutComponent },
  { path: 'contact', component: ContactComponent },
  { path: 'search', component: SearchComponent },
  { path: 'cart', component: CartComponent },
  { path: 'profile', component: ProfileComponent, canActivate: [authGuard] },
  { path: 'book/:id', component: BookDetailsComponent },
  { path: 'privacy-policy', component: PrivacyPolicyComponent },
  { path: 'refund-policy', component: RefundPolicyComponent },
  { path: 'terms-and-conditions', component: TermsAndConditionsComponent },
  { path: 'cookies-policy', component: CookiesPolicyComponent },
  { path: 'copyright-notice', component: CopyrightNoticeComponent },
  { path: 'dmca-policy', component: DmcaPolicyComponent },
  { path: 'terms-of-sale', component: TermsOfSaleComponent },
  {
    path: 'manage-books',
    component: ManageBooksComponent,
    canActivate: [authGuard, adminGuard],
  },
  {
    path: 'add-book',
    component: AddBookComponent,
    canActivate: [authGuard, adminGuard],
  },
  {
    path: 'add-book/:id',
    component: AddBookComponent,
    canActivate: [authGuard, adminGuard],
  },
  {
    path: 'my-books',
    component: MyBooksComponent,
    canActivate: [authGuard],
  },
  { path: 'login', component: SigninComponent },
  { path: 'signup', component: SignupComponent },
  { path: 'forget-password', component: ForgetPasswordComponent },
  { path: 'reset-password', component: ResetPasswordComponent },
  { path: 'not-found', component: NotFoundComponent },
  { path: '**', redirectTo: 'not-found' },
];
