import { Component, Input } from '@angular/core';
import { Book } from '../../data/book';
import { ButtonModule } from 'primeng/button';
import { BooksService } from '../../services/books.service';
import { loadStripe } from '@stripe/stripe-js/pure';
import { environment } from '../../../environments/environment';
import { AuthService } from '../../services/auth.service';
import { Router } from '@angular/router';
import { CartService } from '../../services/cart.service';
import { MessageService } from 'primeng/api';

@Component({
  selector: 'app-buy-buttons',
  standalone: true,
  imports: [ButtonModule],
  templateUrl: './buy-buttons.component.html',
  styleUrl: './buy-buttons.component.css',
})
export class BuyButtonsComponent {
  @Input() book!: Book;

  constructor(
    // private booksService: BooksService,
    private cartService: CartService,
    private authService: AuthService,
    private messageService: MessageService,
    private router: Router
  ) {}

  onBuyEBook() {
    if (this.authService.isLoggedIn.getValue()) {
      this.cartService.addItem({
        id: this.book.id,
        name: this.book.title,
        imageUrl: this.book.frontImageUrl,
        price: this.book.price,
        quantity: 1,
      });
      this.messageService.add({
        summary: 'Added',
        detail: 'Book added to the cart',
        severity: 'info',
      });
    } else {
      this.router.navigate(['/', 'login']);
    }
  }

  onOrderPaperback() {
    window.open(this.book.printUrl, '_blank');
  }
}
