import { Component, Input } from '@angular/core';
import { Book } from '../../data/book';
import { ButtonModule } from 'primeng/button';
import { DownloadService } from '../../services/download.service';

@Component({
  selector: 'app-download-buttons',
  standalone: true,
  imports: [ButtonModule],
  templateUrl: './download-buttons.component.html',
  styleUrl: './download-buttons.component.css',
})
export class DownloadButtonsComponent {
  @Input() book!: Book;
  pdfDownlading = false;
  epubDownlading = false;

  constructor(private downloadService: DownloadService) {}

  onPdf() {
    this.pdfDownlading = true;
    this.downloadService
      .downloadFile(this.book.pdfUrl, this.book.title + '.pdf', 'pdf')
      .subscribe({
        next: (r: any) => {
          this.pdfDownlading = false;
        },
        error: (e: any) => {
          this.pdfDownlading = false;
        },
      });
  }

  onEpub() {
    this.epubDownlading = true;
    this.downloadService
      .downloadFile(this.book.epubUrl, this.book.title + '.epub', 'epub')
      .subscribe({
        next: (r: any) => {
          this.epubDownlading = false;
        },
        error: (e: any) => {
          this.epubDownlading = false;
        },
      });
  }
}
