import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { CarouselModule } from 'primeng/carousel';
import { ButtonModule } from 'primeng/button';
import { TagModule } from 'primeng/tag';
import { TruncatePipe } from '../../pipes/truncate.pipe';
import { BooksService } from '../../services/books.service';
import { Book } from '../../data/book';
import { FeaturedBookService } from '../../services/featured-book.service';
import { first } from 'rxjs';
import { FlipCoverComponent } from '../flip-cover/flip-cover.component';
import { SkeletonModule } from 'primeng/skeleton';
import { BuyButtonsComponent } from '../buy-buttons/buy-buttons.component';
import { LoadingComponent } from '../loading/loading.component';
import { Router } from '@angular/router';

@Component({
  selector: 'app-featured',
  standalone: true,
  imports: [
    CarouselModule,
    ButtonModule,
    TagModule,
    TruncatePipe,
    FlipCoverComponent,
    SkeletonModule,
    BuyButtonsComponent,
    LoadingComponent,
  ],
  templateUrl: './featured.component.html',
  styleUrl: './featured.component.css',
})
export class FeaturedComponent implements OnInit {
  loadingComplete = false;
  book: Book | undefined;
  keyPoints: any;
  constructor(
    private featuredBookService: FeaturedBookService,
    private booksService: BooksService,
    private router: Router
  ) {}

  ngOnInit(): void {
    this.loadingComplete = false;
    this.featuredBookService
      .getFeaturedBook()
      .pipe(first())
      .subscribe({
        next: (b: any) => {
          this.book = b;
          this.keyPoints = this.booksService.getKeyPoints(b);
          this.loadingComplete = true;
        },
        error: (e: any) => {
          this.book = undefined;
          this.loadingComplete = true;
        },
      });
  }

  onSignUp() {
    this.router.navigate(['/', 'signup']);
  }
}
