import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { CheckboxModule } from 'primeng/checkbox';
import { DividerModule } from 'primeng/divider';
import { TreeModule } from 'primeng/tree';
import { InputTextModule } from 'primeng/inputtext';
import { ButtonModule } from 'primeng/button';
import { FormsModule } from '@angular/forms';
import { SearchService } from '../../services/search.service';
import { first } from 'rxjs';
import { DEBOUNCE_TIME } from '../../data/constants';

export interface Filter {
  title: string;
  subtitle: string;
  tags: string;
  series: string;
}

export const EmptyFilter: Filter = {
  title: '',
  subtitle: '',
  tags: '',
  series: '',
};

@Component({
  selector: 'app-filter',
  standalone: true,
  imports: [
    CheckboxModule,
    DividerModule,
    TreeModule,
    InputTextModule,
    ButtonModule,
    FormsModule,
  ],
  templateUrl: './filter.component.html',
  styleUrl: './filter.component.css',
})
export class FilterComponent implements OnInit {
  filterObj: Filter = { ...EmptyFilter };
  @Output() filter = new EventEmitter<Filter>();
  @Output() close = new EventEmitter<void>();

  constructor(private searchService: SearchService) {}

  ngOnInit(): void {
    console.log('[FilterComponent] ngOnInit() at ' + new Date());
    this.searchService.search.pipe(first()).subscribe((t) => {
      switch (t.key) {
        case 'title':
          this.filterObj.title = t.value;
          break;

        case 'series':
          this.filterObj.series = t.value;
          break;

        case 'tag':
          this.filterObj.tags = t.value;
          break;
      }

      if (t) this.filter.next(this.filterObj);
    });
  }

  onDone() {
    this.close.next();
  }

  titleTOH: any;
  onTitleIncludes() {
    if (this.titleTOH) clearTimeout(this.titleTOH);
    this.titleTOH = setTimeout(() => {
      this.filter.next(this.filterObj);
    }, DEBOUNCE_TIME);
  }

  subtitleTOH: any;
  onSubtitleIncludes() {
    if (this.subtitleTOH) clearTimeout(this.subtitleTOH);
    this.subtitleTOH = setTimeout(() => {
      this.filter.next(this.filterObj);
    }, DEBOUNCE_TIME);
  }

  tagsTOH: any;
  onTagsInclude() {
    if (this.tagsTOH) clearTimeout(this.tagsTOH);
    this.tagsTOH = setTimeout(() => {
      this.filter.next(this.filterObj);
    }, DEBOUNCE_TIME);
  }

  seriesTOH: any;
  onSeriesIncludes() {
    if (this.seriesTOH) clearTimeout(this.seriesTOH);
    this.seriesTOH = setTimeout(() => {
      this.filter.next(this.filterObj);
    }, DEBOUNCE_TIME);
  }

  onClearTitle() {
    (this.filterObj.title = ''), this.filter.next(this.filterObj);
  }

  onClearSubtitle() {
    (this.filterObj.subtitle = ''), this.filter.next(this.filterObj);
  }

  onClearTags() {
    (this.filterObj.tags = ''), this.filter.next(this.filterObj);
  }

  onClearSeries() {
    (this.filterObj.series = ''), this.filter.next(this.filterObj);
  }

  onClearFilter() {
    this.filterObj = { ...EmptyFilter };
    this.filter.next(this.filterObj);
  }
}
