import { Component, EventEmitter, Input, Output } from '@angular/core';
import { TruncatePipe } from '../../pipes/truncate.pipe';
import { CommonModule } from '@angular/common';
import { ButtonModule } from 'primeng/button';
import { Router } from '@angular/router';
import { Book } from '../../data/book';
import { BOOK_PROKEN_IMAGE_PLACEHOLDER } from '../../data/constants';

@Component({
  selector: 'app-my-book',
  standalone: true,
  imports: [TruncatePipe, CommonModule, ButtonModule],
  templateUrl: './my-book.component.html',
  styleUrl: './my-book.component.css',
})
export class MyBookComponent {
  today = new Date();
  constructor(private router: Router) {}
  @Input() featured: boolean = false;
  @Input() book!: Book;
  @Input() missingDetails: boolean = false;
  @Output() delete = new EventEmitter<void>();
  @Output() pause = new EventEmitter<boolean>();
  @Output() feature = new EventEmitter<void>();

  onEdit(id: number) {
    this.router.navigate(['/', 'add-book', id]);
  }

  onFeature() {
    this.feature.next();
  }

  onImageClick(id: number) {
    this.router.navigate(['/', 'book', id]);
  }

  onImageError(e: any) {
    e.target.src = BOOK_PROKEN_IMAGE_PLACEHOLDER;
  }

  onDelete() {
    this.delete.next();
  }

  onPlay() {
    this.pause.next(false);
  }

  onPause() {
    this.pause.next(true);
  }
}
