import { Component, Inject, OnInit, PLATFORM_ID } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { ButtonModule } from 'primeng/button';
import { RelatedBooksComponent } from '../../components/related-books/related-books.component';
import { RelatedBooksService } from '../../services/related-books.service';
import { first, take } from 'rxjs';
import { CommonModule, isPlatformBrowser } from '@angular/common';
import { ProgressSpinnerModule } from 'primeng/progressspinner';
import { QuillViewHTMLComponent } from 'ngx-quill';
import { Book } from '../../data/book';
import { BooksService } from '../../services/books.service';
import { FlipCoverComponent } from '../../components/flip-cover/flip-cover.component';
import { BuyButtonsComponent } from '../../components/buy-buttons/buy-buttons.component';
import { LoadingComponent } from '../../components/loading/loading.component';
import { DownloadButtonsComponent } from '../../components/download-buttons/download-buttons.component';
import { BookInfoComponent } from '../../components/book-info/book-info.component';
import { SeriesComponent } from '../../components/series/series.component';
import { SearchService } from '../../services/search.service';
import { TagsComponent } from '../../components/tags/tags.component';
import { DownloadSourceCodeComponent } from '../../components/download-source-code/download-source-code.component';
import { BOOK_PROKEN_IMAGE_PLACEHOLDER } from '../../data/constants';

@Component({
  selector: 'app-book-details',
  standalone: true,
  imports: [
    CommonModule,
    ButtonModule,
    RelatedBooksComponent,
    ProgressSpinnerModule,
    QuillViewHTMLComponent,
    FlipCoverComponent,
    BuyButtonsComponent,
    LoadingComponent,
    DownloadButtonsComponent,
    BookInfoComponent,
    SeriesComponent,
    TagsComponent,
    DownloadSourceCodeComponent,
  ],
  templateUrl: './book-details.component.html',
  styleUrl: './book-details.component.css',
})
export class BookDetailsComponent implements OnInit {
  book!: Book;
  bookId!: any;
  shareUrl = '';
  realtedBooks: Book[] = [];
  expiresOn = '';
  isLoading = false;
  keyPoints: any;
  tags: string[] = [];
  constructor(
    private route: ActivatedRoute,
    private booksService: BooksService,
    private relatedBooksService: RelatedBooksService,
    private searchService: SearchService,
    private router: Router,
    @Inject(PLATFORM_ID) private platformId: any
  ) {}

  ngOnInit(): void {
    this.route.params.subscribe((r) => {
      this.bookId = r['id'];

      this.isLoading = true;
      this.booksService
        .getBook(this.bookId)
        .pipe(first())
        .subscribe({
          next: (book: any) => {
            this.isLoading = false;
            this.book = book;
            this.keyPoints = this.booksService.getKeyPoints(book);
            this.tags = this.booksService.getTagsAsStringArray(book.tags);
            this.loadRelatedBooks(this.book);
          },
          error: (e) => {
            this.isLoading = false;
          },
        });
    });
  }

  loadRelatedBooks(book: Book) {
    this.relatedBooksService
      .getRelatedBooks(book)
      .pipe(take(1))
      .subscribe((r: any) => {
        this.realtedBooks = r;
      });
  }

  onImageError(e: any) {
    e.target.src = BOOK_PROKEN_IMAGE_PLACEHOLDER;
  }

  onBuyEBook() {}

  onOrderPaperback() {}

  onSeries() {
    this.searchService.onSeries(this.book.series);
    this.router.navigate(['/', 'search']);
  }

  onTag(tag: string) {
    this.searchService.onTag(tag);
    this.router.navigate(['/', 'search']);
  }
}
