import { Component, OnInit } from '@angular/core';
import { FeaturedComponent } from '../../components/featured/featured.component';
import { CommonModule } from '@angular/common';
import { TabViewModule } from 'primeng/tabview';
import { Router } from '@angular/router';
import { DividerModule } from 'primeng/divider';
import { AuthService } from '../../services/auth.service';
import { first } from 'rxjs';
import { HomeViewAllComponent } from '../../components/home-view-all/home-view-all.component';
import { BooksService } from '../../services/books.service';
import { BookCardComponent } from '../../components/book-card/book-card.component';
import { Book } from '../../data/book';
import { BOOKS_PAGINATION_TAKE } from '../../data/constants';

@Component({
  selector: 'app-home',
  standalone: true,
  imports: [
    FeaturedComponent,
    CommonModule,
    TabViewModule,
    DividerModule,
    HomeViewAllComponent,
    BookCardComponent,
  ],
  templateUrl: './home.component.html',
  styleUrl: './home.component.css',
})
export class HomeComponent implements OnInit {
  latestBooks: Book[] = [];
  isLoggedIn = false;
  isLoadingBooks = false;

  constructor(
    private router: Router,
    private authService: AuthService,
    private booksService: BooksService
  ) {}

  ngOnInit(): void {
    this.isLoadingBooks = true;
    this.booksService
      .getAll(BOOKS_PAGINATION_TAKE, 0)
      .pipe(first())
      .subscribe({
        next: (r: any) => {
          this.isLoadingBooks = false;
          this.latestBooks = r[0];
        },
        error: (e) => {
          this.isLoadingBooks = false;
        },
      });

    this.authService.isLoggedIn.subscribe((r) => (this.isLoggedIn = r));
  }

  onAdClick(obj: any) {}

  onSignup() {
    this.router.navigate(['/', 'signup']);
  }
}
