import { ChangeDetectorRef, Component, OnInit } from '@angular/core';
import { PaginatorModule } from 'primeng/paginator';
import { first, take } from 'rxjs';
import { DataViewModule } from 'primeng/dataview';
import { ButtonModule } from 'primeng/button';
import { Router } from '@angular/router';
import { CardModule } from 'primeng/card';
import { DividerModule } from 'primeng/divider';
import { TruncatePipe } from '../../pipes/truncate.pipe';
import { TabViewModule } from 'primeng/tabview';
import { CommonModule } from '@angular/common';
import { MyBookComponent } from '../../components/my-book/my-book.component';
import { SkeletonModule } from 'primeng/skeleton';
import { ConfirmationService, MessageService } from 'primeng/api';
import { ConfirmDialogModule } from 'primeng/confirmdialog';
import { ToastModule } from 'primeng/toast';
import { BreadcrumbComponent } from '../../components/breadcrumb/breadcrumb.component';
import { BooksService } from '../../services/books.service';
import { Book } from '../../data/book';
import { FeaturedBookService } from '../../services/featured-book.service';
import { BOOKS_PAGINATION_TAKE } from '../../data/constants';
@Component({
  selector: 'app-my-ads',
  standalone: true,
  imports: [
    PaginatorModule,
    DataViewModule,
    ButtonModule,
    CardModule,
    DividerModule,
    TruncatePipe,
    TabViewModule,
    CommonModule,
    MyBookComponent,
    MyBookComponent,
    SkeletonModule,
    ConfirmDialogModule,
    ToastModule,
    BreadcrumbComponent,
  ],
  templateUrl: './manage-books.component.html',
  styleUrl: './manage-books.component.css',
  providers: [ConfirmationService, MessageService],
})
export class ManageBooksComponent implements OnInit {
  publishedBooks_take = BOOKS_PAGINATION_TAKE;
  publishedBooks_skip = 0;
  publishedBooks_page = 0;
  publishedBooks_total = BOOKS_PAGINATION_TAKE;
  draftBooks_take = BOOKS_PAGINATION_TAKE;
  draftBooks_skip = 0;
  draftBooks_page = 0;
  draftBooks_total = BOOKS_PAGINATION_TAKE;

  publishedBooks: Book[] = [];
  draftBooks: Book[] = [];
  actvIndx = 0;
  isLoadingPublished = false;
  isLoadingDraft = false;

  skeletons = new Array(BOOKS_PAGINATION_TAKE);

  featuredBookId!: number;

  items: any[] = [];
  constructor(
    private booksService: BooksService,
    private router: Router,
    private cdr: ChangeDetectorRef,
    private messagesService: MessageService,
    private featuredBookService: FeaturedBookService
  ) {}

  ngOnInit(): void {
    this.items.push({
      label: 'Manage Books',
      link: '',
    });
    this.loadPublishedBooks();
    this.featuredBookService
      .getFeaturedBook()
      .pipe(first())
      .subscribe((a: any) => {
        this.featuredBookId = a.id;
      });
  }

  onFeatureBook(bookId: number) {
    this.featuredBookService.setFeaturedBook(bookId).subscribe({
      next: async (r) => {
        this.featuredBookId = bookId;
        this.messagesService.add({
          severity: 'info',
          summary: 'Featured',
          detail: 'Book featured successfully',
        });
      },
      error: (e) => {
        console.log(e);
        this.messagesService.add({
          severity: 'error',
          summary: 'Error',
          detail: e.error.message,
        });
      },
    });
  }

  loadPublishedBooks() {
    this.isLoadingPublished = true;
    this.booksService
      .getAdminPublishedBooks(
        this.publishedBooks_take,
        this.publishedBooks_skip
      )
      .pipe(take(1))
      .subscribe({
        next: (books: any) => {
          this.isLoadingPublished = false;
          this.publishedBooks = books['0'];
          this.publishedBooks_total = books['1'];
          this.cdr.markForCheck();
        },
        error: (e: any) => {
          this.isLoadingPublished = false;
          this.cdr.markForCheck();
        },
      });
  }

  loadDraftBooks() {
    this.isLoadingDraft = true;
    this.booksService
      .getAdminNotPublishedBooks(this.draftBooks_take, this.draftBooks_skip)
      .pipe(take(1))
      .subscribe({
        next: (books: any) => {
          this.isLoadingDraft = false;
          this.draftBooks = books['0'];
          this.draftBooks_total = books['1'];
          this.cdr.markForCheck();
        },
        error: (e: any) => {
          this.isLoadingDraft = false;
          this.cdr.markForCheck();
        },
      });
  }

  onPublishedBooksPageChange(obj: any) {
    this.publishedBooks_page = obj.page;
    this.publishedBooks_skip = obj.page * obj.rows;
    this.publishedBooks_take = obj.rows;
    this.loadPublishedBooks();
  }

  onDraftBooksPageChange(obj: any) {
    this.draftBooks_page = obj.page;
    this.draftBooks_skip = obj.page * obj.rows;
    this.draftBooks_take = obj.rows;
    this.loadDraftBooks();
  }
  onAdd() {
    this.router.navigate(['/', 'add-book']);
  }

  onTabChange(e: any) {
    if (e.index === 0) {
      this.loadPublishedBooks();
    } else if (e.index === 1) {
      this.loadDraftBooks();
    }
  }

  // onDelete(adId: string) {
  //   this.confirmationService.confirm({
  //     message: `
  // <h3>Are you sure you want to delete this draft?</h3>
  //       `,
  //     header: 'Delete draft',
  //     icon: 'pi pi-info-circle',
  //     acceptButtonStyleClass: 'p-button-danger p-button-text',
  //     rejectButtonStyleClass: 'p-button-text p-button-text',
  //     acceptIcon: 'none',
  //     rejectIcon: 'none',

  //     accept: () => {
  //       this.adsService
  //         .deleteAd(+adId)
  //         .pipe(first())
  //         .subscribe((t: any) => {
  //           this.loadDraftBooks();
  //         });
  //       this.messageService.add({
  //         severity: 'info',
  //         summary: 'Confirmed',
  //         detail: 'Draft deleted!',
  //       });
  //     },
  //     reject: () => {},
  //   });
  // }

  //   onStopAd(adId: string) {
  //     this.confirmationService.confirm({
  //       message: `
  // <h3>Are you sure you want to stop this ad?</h3>
  // <div>It will be removed from the search results and from all pages.</div>
  // <div>This action cannot be reversed.</div>
  //       `,
  //       header: 'Stop Ad Confirmation',
  //       icon: 'pi pi-info-circle',
  //       acceptButtonStyleClass: 'p-button-danger p-button-text',
  //       rejectButtonStyleClass: 'p-button-text p-button-text',
  //       acceptIcon: 'none',
  //       rejectIcon: 'none',

  //       accept: () => {
  //         this.adsService
  //           .stopAd(+adId)
  //           .pipe(first())
  //           .subscribe((t: any) => {
  //             // this.cdr.markForCheck();
  //             // this.loadAd();
  //             // //window.location.href;
  //           });
  //         this.messageService.add({
  //           severity: 'info',
  //           summary: 'Confirmed',
  //           detail: 'Ad stopped',
  //         });
  //       },
  //       reject: () => {},
  //     });
  //   }

  // onPauseAd(value: boolean, adId: string) {
  //   this.adsService
  //     .pauseAd(value, +adId)
  //     .pipe(first())
  //     .subscribe((t: any) => {
  //       let found;
  //       if (this.actvIndx === 0) {
  //         found = this.publishedBooks.find((c) => c.id === t.id);
  //       } else if (this.actvIndx === 1) {
  //         found = this.draftBooks.find((c) => c.id === t.id);
  //       } else if (this.actvIndx === 2) {
  //         found = this.expiredBooks.find((c) => c.id === t.id);
  //       }
  //       if (found) found.paused = t.paused;
  //       if (t.paused) {
  //         this.messageService.add({
  //           severity: 'info',
  //           summary: 'Paused',
  //           detail: 'Ad paused!',
  //         });
  //       } else {
  //         this.messageService.add({
  //           severity: 'success',
  //           summary: 'Resumed',
  //           detail: 'Ad resumed successfuly!',
  //         });
  //       }
  //     });
  // }
}
