import { Component, OnInit } from '@angular/core';
import {
  AbstractControl,
  FormBuilder,
  ReactiveFormsModule,
  ValidationErrors,
  ValidatorFn,
  Validators,
} from '@angular/forms';
import { ToastModule } from 'primeng/toast';
import { PanelModule } from 'primeng/panel';
import { StarComponent } from '../../components/star/star.component';
import { InputTextModule } from 'primeng/inputtext';
import { ButtonModule } from 'primeng/button';
import { take } from 'rxjs';
import { MessageService } from 'primeng/api';
import { AuthService } from '../../services/auth.service';
import { DividerModule } from 'primeng/divider';

@Component({
  selector: 'app-profile',
  standalone: true,
  imports: [
    ToastModule,
    ReactiveFormsModule,
    PanelModule,
    StarComponent,
    InputTextModule,
    ButtonModule,
    DividerModule,
  ],
  templateUrl: './profile.component.html',
  styleUrl: './profile.component.css',
})
export class ProfileComponent implements OnInit {
  form = this.fb.group({
    firstname: this.fb.control(''),
    lastname: this.fb.control(''),
    email: this.fb.control(
      {
        value: '',
        disabled: true,
      },
      [Validators.required, Validators.email]
    ),
  });

  constructor(
    private fb: FormBuilder,
    private authService: AuthService,
    private messagesService: MessageService
  ) {}

  ngOnInit(): void {
    this.authService
      .getProfile()
      .pipe(take(1))
      .subscribe((p: any) => {
        console.log('rs p : ', p);
        this.form.patchValue({
          firstname: p.firstname,
          lastname: p.lastname,
          email: p.email,
        });
      });
  }

  onSubmit() {
    this.authService
      .updateProfile({
        firstname: this.form.value.firstname!,
        lastname: this.form.value.lastname!,
      })
      .pipe(take(1))
      .subscribe({
        next: (r: any) => {
          this.messagesService.add({
            summary: 'Success',
            severity: 'info',
            detail: 'Saved successfully',
          });
          this.authService.user.next({
            fullname:
              this.form.value.firstname + ' ' + this.form.value.lastname,
            email: this.form.value.email!,
          });
        },
        error: (e) => {
          this.messagesService.add({
            summary: 'Error',
            severity: 'error',
            detail: 'Error updating profile ' + e.error.message,
          });
        },
      });
  }
}
