import { Component, OnInit } from '@angular/core';
import {
  EmptyFilter,
  Filter,
  FilterComponent,
} from '../../components/filter/filter.component';
import { ButtonModule } from 'primeng/button';
import { DialogModule } from 'primeng/dialog';
import { DividerModule } from 'primeng/divider';
import { first } from 'rxjs';
import { Book } from '../../data/book';
import { BooksService } from '../../services/books.service';
import { BookCardComponent } from '../../components/book-card/book-card.component';
import { PaginatorModule } from 'primeng/paginator';
import { LoadingComponent } from '../../components/loading/loading.component';
import { ResizeDirective } from '../../directives/resize.directive';
import { MobileService } from '../../services/mobile.service';
import { BOOKS_PAGINATION_TAKE } from '../../data/constants';

@Component({
  selector: 'app-courses',
  standalone: true,
  imports: [
    FilterComponent,
    ButtonModule,
    DialogModule,
    DividerModule,
    BookCardComponent,
    PaginatorModule,
    LoadingComponent,
    ResizeDirective,
  ],
  templateUrl: './search.component.html',
  styleUrl: './search.component.css',
})
export class SearchComponent implements OnInit {
  books: Book[] = [];
  filterOpen = false;
  filter: Filter = EmptyFilter;
  page: number = 0;
  take: number = BOOKS_PAGINATION_TAKE;
  skip: number = 0;
  total: number = BOOKS_PAGINATION_TAKE;
  isLoading = false;
  shareUrl = '';
  isMobile = false;
  constructor(
    private booksService: BooksService,
    private mobileService: MobileService
  ) {}

  ngOnInit(): void {
    this.mobileService.mobile.subscribe(
      (isMobile) => (this.isMobile = isMobile)
    );
  }

  onOpenFilter() {
    this.filterOpen = true;
  }

  onFilter(filter: Filter) {
    console.log('OnFilter: ', filter);
    this.filter = filter;
    this.page = 0;
    this.skip = 0;
    this.take = BOOKS_PAGINATION_TAKE;
    this.loadBooks();
  }

  onPage(obj: any) {
    console.log('OnPage: ', obj);
    this.page = obj.page;
    this.skip = obj.page * obj.rows;
    this.take = obj.rows;
    this.loadBooks();
  }

  loadBooks() {
    this.isLoading = true;
    let obj = {};
    if (this.filter) {
      obj = {
        ...obj,
        ...this.filter,
      };
    }
    this.booksService
      .getFiltered(obj, this.take, this.skip)
      .pipe(first())
      .subscribe({
        next: (r: any) => {
          this.isLoading = false;
          this.books = r[0];
          this.total = r[1];
        },
        error: (e: any) => {
          this.isLoading = false;
        },
      });
  }

  onMobile(value: boolean) {
    this.isMobile = value;
  }
}
