import { HttpClient } from '@angular/common/http';
import { Inject, Injectable, PLATFORM_ID } from '@angular/core';
import { environment } from '../../environments/environment';
import { BehaviorSubject, switchMap, tap } from 'rxjs';
import { Router } from '@angular/router';
import { isPlatformBrowser } from '@angular/common';
import { CartService } from './cart.service';
import {
  KEY_ACCESS_TOKEN,
  KEY_REFRESH_TOKEN,
  ADMIN_EMAIL,
  KEY_USER,
} from '../data/constants';

@Injectable({
  providedIn: 'root',
})
export class AuthService {
  isLoggedIn = new BehaviorSubject<boolean>(false);
  isAdmin = new BehaviorSubject<boolean>(false);
  user = new BehaviorSubject<{ fullname: string; email: string }>({
    fullname: '',
    email: '',
  });
  userObj: any = {};
  constructor(
    private http: HttpClient,
    private router: Router,
    @Inject(PLATFORM_ID) private platformId: any,
    private cartService: CartService
  ) {}

  login(username: string, password: string) {
    return this.http
      .post(
        environment.API_URL + '/auth/login',
        {
          username,
          password,
        },
        {
          headers: {
            'Content-Type': 'application/json',
          },
          params: {
            sub: 'books',
          },
        }
      )
      .pipe(
        switchMap((r: any) => {
          if (isPlatformBrowser(this.platformId)) {
            localStorage.setItem(KEY_ACCESS_TOKEN, r.accessToken);
            localStorage.setItem(KEY_REFRESH_TOKEN, r.refreshToken);
          }
          this.userObj = {
            ...this.userObj,
            id: r.id,
            email: r.email,
          };
          return this.getProfile();
        }),
        tap((r: any) => {
          this.userObj = {
            ...this.userObj,
            firstname: r.firstname,
            lastname: r.lastname,
          };
          if (isPlatformBrowser(this.platformId)) {
            localStorage.setItem(KEY_USER, JSON.stringify(this.userObj));
          }
          this.user.next({
            fullname: this.userObj.firstname + ' ' + this.userObj.lastname,
            email: this.userObj.email,
          });
          this.isLoggedIn.next(true);
          if (r.email === ADMIN_EMAIL) this.isAdmin.next(true);
          this.router.navigate(['/']);
          this.cartService.loadCart();
        })
      );
  }

  signup(firstname: string, lastname: string, email: string, password: string) {
    return this.http
      .post(
        environment.API_URL + '/auth/register',
        {
          firstname,
          lastname,
          email,
          password,
        },
        {
          headers: {
            'Content-Type': 'application/json',
          },
          params: {
            sub: 'books',
          },
        }
      )
      .pipe(
        switchMap((r: any) => {
          if (isPlatformBrowser(this.platformId)) {
            localStorage.setItem(KEY_ACCESS_TOKEN, r.accessToken);
            localStorage.setItem(KEY_REFRESH_TOKEN, r.refreshToken);
          }
          this.userObj = {
            ...this.userObj,
            id: r.id,
            email: r.email,
          };
          return this.getProfile();
        }),
        tap((r: any) => {
          this.userObj = {
            ...this.userObj,
            firstname: r.firstname,
            lastname: r.lastname,
          };
          if (isPlatformBrowser(this.platformId)) {
            localStorage.setItem(KEY_USER, JSON.stringify(this.userObj));
          }
          this.user.next({
            fullname: this.userObj.firstname + ' ' + this.userObj.lastname,
            email: this.userObj.email,
          });
          this.isLoggedIn.next(true);
          if (r.email === ADMIN_EMAIL) this.isAdmin.next(true);
          this.router.navigate(['/']);
          this.cartService.loadCart();
        })
      );
  }

  logout() {
    if (isPlatformBrowser(this.platformId)) {
      localStorage.removeItem(KEY_ACCESS_TOKEN);
      localStorage.removeItem(KEY_USER);
    }
    this.isLoggedIn.next(false);
    this.isAdmin.next(false);
    this.user.next({
      fullname: '',
      email: '',
    });
    this.cartService.clear();
    this.router.navigate(['/']);
  }

  getProfile() {
    return this.http.get(environment.API_URL + '/users/profile', {
      headers: {
        'Content-Type': 'application/json',
      },
    });
  }

  updateProfile(body: { firstname: string; lastname: string }) {
    return this.http.put(
      environment.API_URL + '/users/profile',
      {
        firstname: body.firstname,
        lastname: body.lastname,
      },
      {
        headers: {
          'Content-Type': 'application/json',
        },
      }
    );
  }

  requestResetPassword(email: string) {
    return this.http.post(
      environment.API_URL + '/auth/request-reset-password',
      { email },
      {
        headers: { 'Content-Type': 'application/json' },
        params: {
          sub: 'books',
        },
      }
    );
  }

  resetPassword(email: string, token: string, password: string) {
    return this.http.post(
      environment.API_URL + '/auth/reset-password',
      { email, token, password },
      {
        headers: { 'Content-Type': 'application/json' },
        params: {
          sub: 'books',
        },
      }
    );
  }
}
