import { HttpClient } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { environment } from '../../environments/environment';
import { Book } from '../data/book';

@Injectable({
  providedIn: 'root',
})
export class BooksService {
  constructor(private http: HttpClient) {}

  getImages(folderPath: string) {
    return {
      front:
        environment.DOWNLOAD_BASE_URL +
        '/' +
        folderPath +
        '/cover/' +
        'front-313.jpg',
      back:
        environment.DOWNLOAD_BASE_URL +
        '/' +
        folderPath +
        '/cover/' +
        'back-313.jpg',
      side:
        environment.DOWNLOAD_BASE_URL +
        '/' +
        folderPath +
        '/cover/' +
        'side.jpg',
    };
  }

  getFiles(folderPath: string) {
    return {
      pdf:
        environment.DOWNLOAD_BASE_URL + '/' + folderPath + '/pdf/' + 'book.pdf',
      epub:
        environment.DOWNLOAD_BASE_URL +
        '/' +
        folderPath +
        '/pdf/' +
        'book.epub',
    };
  }

  buyBook(id: number) {
    return this.http.get(environment.API_URL + '/books/buy-book/' + id, {
      headers: {
        'Content-Type': 'application/json',
      },
    });
  }

  checkout(ids: string) {
    return this.http.get(environment.API_URL + '/books/checkout', {
      headers: {
        'Content-Type': 'application/json',
      },
      params: {
        ids,
      },
    });
  }

  getBook(id: number) {
    return this.http.get(environment.API_URL + '/books/' + id, {
      headers: { 'Content-Type': 'application-json' },
    });
  }

  getKeyPoints(book: Book) {
    let keyPoint1 = '';
    let keyPoint2 = '';
    let keyPoint3 = '';

    const arr = book?.keyPoints?.split('|');
    if (arr && arr.length > 0) {
      keyPoint1 = arr[0] ?? '';
      keyPoint2 = arr[1] ?? '';
      keyPoint3 = arr[2] ?? '';
    }
    return {
      keyPoint1,
      keyPoint2,
      keyPoint3,
    };
  }

  setKeyPoinst(
    book: Book,
    keyPoint1: string,
    keyPoint2: string,
    keyPoint3: string
  ) {
    if (book) {
      book.keyPoints = keyPoint1 + '|' + keyPoint2 + '|' + keyPoint3;
    }
  }

  getTagsAsStringArray(tags: string) {
    let tgsAr: string[] = [];
    if (tags) {
      if (tags.includes(',')) {
        tgsAr = tags.split(',').map((t) => t.trim());
      } else {
        tgsAr = [tags.trim()];
      }
    }
    return tgsAr;
  }

  getFiltered(filter: any, take: number, skip: number) {
    return this.http.post(
      environment.API_URL + '/books/filter',
      {
        filter,
      },
      {
        params: {
          take,
          skip,
        },
        headers: {
          'Content-Type': 'application/json',
        },
      }
    );
  }

  downloadFile(bookId: number, type: string) {
    return this.http.get(environment.API_URL + '/download', {
      headers: { 'Content-Type': 'application-json' },
      params: {
        bookId,
        type,
      },
    });
  }

  getAll(take: number, skip: number) {
    return this.http.get(environment.API_URL + '/books/all', {
      params: {
        take,
        skip,
      },
      headers: {
        'Content-Type': 'application-json',
      },
    });
  }

  getAllForSeries(series: string, take: number, skip: number) {
    return this.http.get(environment.API_URL + '/books/all-series', {
      params: {
        series,
        take,
        skip,
      },
      headers: {
        'Content-Type': 'application-json',
      },
    });
  }

  getAllForTags(tags: string, take: number, skip: number) {
    return this.http.get(environment.API_URL + '/books/all-tags', {
      params: {
        tags,
        take,
        skip,
      },
      headers: {
        'Content-Type': 'application-json',
      },
    });
  }

  getAdminPublishedBooks(take: number, skip: number) {
    return this.http.get(environment.API_URL + '/books/admin-published-books', {
      params: {
        take,
        skip,
      },
      headers: {
        'Content-Type': 'application-json',
      },
    });
  }

  getAdminNotPublishedBooks(take: number, skip: number) {
    return this.http.get(
      environment.API_URL + '/books/admin-not-published-books',
      {
        params: {
          take,
          skip,
        },
        headers: {
          'Content-Type': 'application-json',
        },
      }
    );
  }

  addBook(book: any) {
    return this.http.post(environment.API_URL + '/books', book, {
      headers: {
        'Content-Type': 'application/json',
      },
    });
  }

  updateBook(book: any) {
    return this.http.put(environment.API_URL + '/books/' + book.id, book, {
      headers: {
        'Content-Type': 'application/json',
      },
    });
  }

  publishBook(bookId: number, published: boolean) {
    return this.http.put(
      environment.API_URL + '/books/publish/' + bookId,
      {
        published,
      },
      {
        headers: {
          'Content-Type': 'application/json',
        },
      }
    );
  }

  deleteBook(bookId: number) {
    return this.http.delete(environment.API_URL + '/books/' + bookId, {
      headers: {
        'Content-Type': 'application/json',
      },
    });
  }
}
