import { HttpClient } from '@angular/common/http';
import { Inject, Injectable, PLATFORM_ID, signal } from '@angular/core';
import { environment } from '../../environments/environment';
import { first } from 'rxjs';
import { isPlatformBrowser } from '@angular/common';
import { Cart, CartItem } from '../data/cart';

@Injectable({
  providedIn: 'root',
})
export class CartService {
  cart = signal<Cart>({
    items: [],
    count: 0,
    total: 0,
  });

  constructor(
    @Inject(PLATFORM_ID) private platformId: any,
    private http: HttpClient
  ) {
    if (isPlatformBrowser(this.platformId)) {
      this.loadCart();
    }
  }

  loadCart() {
    this.http
      .get(environment.API_URL + '/cart', {
        headers: {
          'Content-Type': 'application/json',
        },
        params: {
          sub: 'books',
        },
      })
      .pipe(first())
      .subscribe((t: any) => {
        if (t && t.cart) {
          this.cart.set(JSON.parse(t.cart));
        }
      });
  }

  addItem(item: CartItem) {
    const itemObj = this.cart().items.find((t) => t.id === item.id);
    if (itemObj) {
      // this.increaseItem(itemObj);
    } else {
      this.cart.update((prevCart) => ({
        ...prevCart,
        items: [...prevCart.items, item],
        count: prevCart.count + 1,
        total: this.roundNumber(+prevCart.total + +item.price),
      }));
      this.saveCart();
    }
  }

  saveCart() {
    this.http
      .post(
        environment.API_URL + '/cart',
        {
          cart: JSON.stringify(this.cart()),
        },
        {
          headers: {
            'Content-Type': 'application/json',
          },
          params: {
            sub: 'books',
          },
        }
      )
      .pipe(first())
      .subscribe();
  }

  roundNumber(v: number) {
    const r = Math.round(v * 100) / 100;
    console.log(r);
    return r;
  }

  increaseItem(item: CartItem) {
    this.cart.update((prevCart) => {
      const newCart = {
        ...prevCart,
        items: [...prevCart.items],
      };
      const itemObj = newCart.items.find((t) => t.id === item.id);
      itemObj!.quantity = +itemObj!.quantity + 1;
      newCart.count++;
      newCart.total += +itemObj!.price;
      newCart.total = this.roundNumber(+newCart.total);
      return newCart;
    });
  }

  decreaseItem(item: CartItem) {
    this.cart.update((prevCart) => {
      const newCart = {
        ...prevCart,
        items: [...prevCart.items],
      };
      const itemObj = newCart.items.find((t) => t.id === item.id);
      itemObj!.quantity = +itemObj!.quantity - 1;
      newCart.count--;
      newCart.total -= +itemObj!.price;
      newCart.total = this.roundNumber(+newCart.total);
      return newCart;
    });
  }

  removeItem(item: CartItem) {
    this.cart.update((prevCart) => {
      const newCart = {
        ...prevCart,
        items: [...prevCart.items.filter((t) => t.id !== item.id)],
      };
      const itemObj = prevCart.items.find((t) => t.id === item.id);
      newCart.count -= +itemObj!.quantity;
      newCart.total -= +itemObj!.price * +itemObj!.quantity;
      newCart.total = this.roundNumber(+newCart.total);
      return newCart;
    });
    this.saveCart();
  }

  clear() {
    this.cart.set({
      items: [],
      count: 0,
      total: 0,
    });
  }
}
