import { Injectable } from '@angular/core';
import { of, switchMap } from 'rxjs';
import { BooksService } from './books.service';
import { Book } from '../data/book';
import { BOOKS_RELATED_NUMBER } from '../data/constants';

@Injectable({
  providedIn: 'root',
})
export class RelatedBooksService {
  constructor(private booksService: BooksService) {}

  getRelatedBooks(book: Book) {
    let results: any[] = [];

    if (book.series) {
      return this.booksService
        .getAllForSeries(book.series, BOOKS_RELATED_NUMBER, 0)
        .pipe(
          switchMap((r: any) => {
            results = [...results, ...r[0]];
            const length = results.length;
            if (length >= BOOKS_RELATED_NUMBER)
              return of([results, results.length]);
            else {
              return this.booksService.getAllForTags(
                book.tags,
                BOOKS_RELATED_NUMBER,
                0
              );
            }
          }),
          switchMap((r: any) => {
            results = [...results, ...r[0]];
            return of(this.filterRepeatedItems(book.id, results));
          })
        );
    } else {
      return this.booksService
        .getAllForTags(book.tags, BOOKS_RELATED_NUMBER, 0)
        .pipe(
          switchMap((r: any) => {
            results = [...results, ...r[0]];
            const length = results.length;
            if (length >= BOOKS_RELATED_NUMBER)
              return of([results, results.length]);
            else {
              return this.booksService.getAllForSeries(
                book.series,
                BOOKS_RELATED_NUMBER,
                0
              );
            }
          }),
          switchMap((r: any) => {
            results = [...results, ...r[0]];
            return of(this.filterRepeatedItems(book.id, results));
          })
        );
    }
  }

  filterRepeatedItems(bookId: number, results: Book[]) {
    let r: Book[] = [];
    results.forEach((t) => {
      if (t.id !== bookId && !r.map((b) => b.id).includes(t.id)) {
        r.push(t);
      }
    });
    return r.slice(0, BOOKS_RELATED_NUMBER);
  }
}
